#!/bin/sh

exitFail () {
		log "Error: $1"
		exit 1
}

# This script is run from the temporary directory that the upgrade is
# extracted to
echo "Running free space"

rm -rf /cathexis/tmp
if [ $? -ne 0 ]; then 
 exitFail "Failed removing /cathexis/tmp" 
fi

if [ ! -d "/hiwrite" ]; then
echo "Creating hiwrite directory"
  mkdir -p /hiwrite
  if [ $? -ne 0 ]; then 
    exitFail "Failed creating /hiwrite dir" 
  fi
	mount -t jffs2 /dev/mtdblock7 /hiwrite
  if [ $? -ne 0 ]; then 
    exitFail "Failed mounting /dev/mtdblock7" 
  fi
	mkdir -p /hiwrite/logs
  if [ $? -ne 0 ]; then 
    exitFail "Failed making /space/logs" 
  fi
	rm -rf /cathexis/logs
	ln -s /hiwrite/logs /cathexis/logs
	if [ $? -ne 0 ]; then 
		exitFail "Failed linking /hiwrite/logs and /cathexis/logs" 
	fi
fi

if [ ! -d "/space" ]; then
echo "Creating space directory"
  mkdir -p /space
  if [ $? -ne 0 ]; then 
    exitFail "Failed creating /space dir" 
  fi
	mount -t jffs2 /dev/mtdblock9 /space
  if [ $? -ne 0 ]; then 
    exitFail "Failed mounting /dev/mtdblock9" 
  fi
	mkdir -p /space/tmp
  if [ $? -ne 0 ]; then 
    exitFail "Failed making /space/tmp" 
  fi
fi

echo "Linking /space/tmp and /cathexis/tmp"	
ln -s /space/tmp /cathexis/tmp
if [ $? -ne 0 ]; then 
  exitFail "Failed linking /space/tmp and /cathexis/tmp" 
fi

echo "Removing tools from directory"
rm -rf /cathexis/bin/systeminfo
rm -rf /cathexis/bin/verify_boot_parameters
rm -rf /cathexis/bin/cat_analytics
rm -rf /cathexis/bin/tool_*

echo "Removing core files"	
rm -rf /cathexis/bin/*.core
if [ $? -ne 0 ]; then 
  exitFail "Failed removing /cathexis/bin/core" 
fi

echo "Removing tgz files"	
rm -rf /cathexis/bin/*.tgz
if [ $? -ne 0 ]; then 
  exitFail "Failed removing /cathexis/bin/*.tgz" 
fi

echo "Done"

exit 0
